from requests import post as request
from os import getenv
from cli.runcmd import runcmd

GITHUB_API_URL = "https://api.github.com"
TOKEN = getenv("github_ogrenilen_token")

class repository:
    def __init__(self):
        pass

    @staticmethod
    def create(repo_name: str, token: str = TOKEN, private: bool = False):
        url = f"{GITHUB_API_URL}/user/repos"
        
        headers = {
            "Authorization": f"token {getenv(token) if token != None else TOKEN}",
            "Accept": "application/vnd.github.v3+json"
        }
        
        data = {
            "name": repo_name,
            "private": private
        }

        response = request(url, json=data, headers=headers)

        if response.status_code == 201:
            # init repository
            runcmd(f"git init {repo_name}", "initializing repository...")

            # set remote
            runcmd(f"git remote add origin https://github.com/OkuldaOgrenilen/{repo_name}.git", "setting remote address...")

            # set branch
            runcmd(f"git branch -M main", "setting branch...")
        else:
            print("     [bold red]Github repository oluşturulurken bir sorun meydana geldi!![/bold red]")

if __name__ == "__main__":
    repository.create("kariyer-planlama")



#!/usr/bin/env python
from typing import Optional
from rich import print
from typing_extensions import Annotated
from typer import run, Exit, Argument, Option
from cli.maker import make
from cli.repo import repository
from cli.template import template

__version__ = "0.1.9"

# Yeni bir depo oluşturmak için kullanılır.
def create_new_repo(repo: str = None, token: str = None):
    # depo belirtilmiş ve metin olarak belirtilmiş ise...
    if repo is not None and type(repo) == str:
        print("     [green bold]Creating a lesson...[/green bold]")

        # Yeni bir klasör oluşturuyoruz ve aynı isim ile yeni bir github deposu oluşturuyoruz.
        repository.create(repo, token)

        try:
            template(repo)
        except Exception as err:
            print(f"[bold white][red]{err}[/red] Template dosyaları oluşturulurken bir sorun meydana geldi![/bold white]")
            raise Exit()
            
        print(f"     [bold green]Successfully created[bold green] [bold white]{make.absjoiner([repo])}[/bold white]")


def main(
    new: Annotated[Optional[str], Argument(help="Yeni bir depo oluşturmak için depo adını belirtiniz.")] = None,
    version: Annotated[bool, Option(help="Kullanmakta olduğunuz on-on sürümünü gösterir.")] = False,
    token: Annotated[Optional[str], Option(help="Özel bir token belirtiniz.")] = None
    ):
    
    if version:
        print(__version__)
        raise Exit()

    if new is not None:
        create_new_repo(new, token)
    else:
        print(f"[bold red]Please provide a valid [white]lesson name[/white][/bold red]")
    

def exec():
    run(main)

if __name__ == "__main__":
    exec()